#region Licence
// Copyright (c) 2007 James Gregory (james@jagregory.com)
// All rights reserved.
// 
// Redistribution and use in source and binary forms, with or without modification,
// are permitted provided that the following conditions are met:
// 
//     * Redistributions of source code must retain the above copyright notice,
//     this list of conditions and the following disclaimer.
//     * Redistributions in binary form must reproduce the above copyright notice,
//     this list of conditions and the following disclaimer in the documentation
//     and/or other materials provided with the distribution.
//     * Neither the name of James Gregory nor the names of its
//     contributors may be used to endorse or promote products derived from this
//     software without specific prior written permission.
// 
// THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
// ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
// WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
// DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE
// FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
// DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
// SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
// CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
// OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
// THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#endregion

using System.Web.UI.WebControls;
using NUnit.Framework;
using Rhino.Mocks;

namespace JAGregory.Controls.Tests
{
	[TestFixture]
	public class DeleGridSorterTests
	{
		[Test]
		public void SortFieldSetOnIntialSort()
		{
			IDeleGrid grid = MockRepository.GenerateStub<IDeleGrid>();
			ISorter sorter = new DeleGridSorter(grid);
			string sortExpression = "fieldName";

			sorter.Store(sortExpression);

			Assert.AreEqual(sortExpression, grid.SortingField, "SortingField should match expression passed into Store.");
		}

		[Test]
		public void SortDirectionSetOnIntialSort()
		{
			IDeleGrid grid = MockRepository.GenerateStub<IDeleGrid>();
			ISorter sorter = new DeleGridSorter(grid);

			sorter.Store("field");

			Assert.AreEqual(grid.SortingDirection, SortDirection.Descending, "Initial sort should set direction to Desc.");
		}

		[Test]
		public void SortDirectionGetsInvertedOnRepeatedSort()
		{
			IDeleGrid grid = MockRepository.GenerateStub<IDeleGrid>();
			ISorter sorter = new DeleGridSorter(grid);

			sorter.Store("field");

			Assert.AreEqual(grid.SortingDirection, SortDirection.Descending, "Initial sort should set direction to Desc.");

			sorter.Store("field");

			Assert.AreEqual(grid.SortingDirection, SortDirection.Ascending, "Subsequent sort should set direction back to Asc.");

			sorter.Store("field");

			Assert.AreEqual(grid.SortingDirection, SortDirection.Descending, "Third sort should set direction back to Desc again.");
		}

		[Test]
		public void SortDirectionGetsResetOnNewFieldSort()
		{
			IDeleGrid grid = MockRepository.GenerateStub<IDeleGrid>();
			ISorter sorter = new DeleGridSorter(grid);

			sorter.Store("field");
			sorter.Store("field2");

			Assert.AreEqual(grid.SortingDirection, SortDirection.Descending, "Sort for new field should set direction to Desc.");

			sorter.Store("field");
			sorter.Store("field");
			sorter.Store("field2");

			Assert.AreEqual(grid.SortingDirection, SortDirection.Descending, "Regardless of previous sorts, sort for new field should set direction to Desc.");
		}
	}
}